/*
 * Generic file access functions.
 *
 * Copyright (C) 2019, 2022 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <stdio.h>
#include <string.h>
#include <sys/stat.h>
#include <sys/types.h>

#include "file.h"



/* Test object types in the external environment. */

int isdir(const char *name)
{
  struct stat st;

  if (!lstat(name, &st))
    return S_ISDIR(st.st_mode);
  else
    return 0;
}

int isdir_dirname(const char *name)
{
  char dirname[strlen(name) + 1];
  char *s;

  strcpy(dirname, name);
  s = strrchr(dirname, (int) '/');

  if (s != NULL)
    *s = '\0';

  return isdir(dirname);
}

int isfile(const char *name)
{
  struct stat st;

  if (!lstat(name, &st))
    return S_ISREG(st.st_mode);
  else
    return 0;
}

/* Open a file in the external environment. */

FILE *open_file_in_dir(const char *dirname, const char *basename,
                       const char *mode)
{
    char pathname[strlen(dirname) + strlen(basename) + 1];

    strcpy(pathname, dirname);
    strcat(pathname, "/");
    strcat(pathname, basename);

    return fopen(pathname, mode);
}

/* vim: tabstop=4 expandtab shiftwidth=4
*/
